CommandSyntaxErrorKind

Enum CommandSyntaxErrorKind 

pub(crate) enum CommandSyntaxErrorKind {
Show 27 variants UnknownCommand, UnknownArgument, Dynamic(Box<TextComponent>), ExpectedStartOfQuote, ExpectedEndOfQuote, InvalidEscape(char), InvalidBool(Box<str>), InvalidInt(Box<str>), ExpectedInt, InvalidLong(Box<str>), ExpectedLong, InvalidDouble(Box<str>), ExpectedDouble, InvalidFloat(Box<str>), ExpectedFloat, ExpectedBool, ExpectedSymbol(char), LiteralIncorrect(Box<str>), IntegerTooLow { found: i32, minimum: i32, }, IntegerTooHigh { found: i32, maximum: i32, }, LongTooLow { found: i64, minimum: i64, }, LongTooHigh { found: i64, maximum: i64, }, FloatTooLow { found: f32, minimum: f32, }, FloatTooHigh { found: f32, maximum: f32, }, DoubleTooLow { found: f64, minimum: f64, }, DoubleTooHigh { found: f64, maximum: f64, }, ExpectedArgumentSeparator,
}
Identifies a Brigadier parsing or command execution error.

Variants



UnknownCommand

No executable command matched the input.



UnknownArgument

A command matched, but trailing input did not.



Dynamic(Box<TextComponent>)

A command supplied a rich runtime failure message.



ExpectedStartOfQuote

A quoted string did not start with a quote.



ExpectedEndOfQuote

A quoted string reached the end of its input.



InvalidEscape(char)

A quoted string contained an unsupported escape.



InvalidBool(Box<str>)

A boolean did not contain true or false.



InvalidInt(Box<str>)

An integer could not be parsed.



ExpectedInt

No integer was present.



InvalidLong(Box<str>)

A long could not be parsed.



ExpectedLong

No long was present.



InvalidDouble(Box<str>)

A double could not be parsed.



ExpectedDouble

No double was present.



InvalidFloat(Box<str>)

A float could not be parsed.



ExpectedFloat

No float was present.



ExpectedBool

No boolean was present.



ExpectedSymbol(char)

An expected symbol was not present.



LiteralIncorrect(Box<str>)

A literal node did not match its configured text.



IntegerTooLow

An integer was below its configured minimum.

Fields

found: i32
minimum: i32


IntegerTooHigh

An integer was above its configured maximum.

Fields

found: i32
maximum: i32


LongTooLow

A long was below its configured minimum.

Fields

found: i64
minimum: i64


LongTooHigh

A long was above its configured maximum.

Fields

found: i64
maximum: i64


FloatTooLow

A float was below its configured minimum.

Fields

found: f32
minimum: f32


FloatTooHigh

A float was above its configured maximum.

Fields

found: f32
maximum: f32


DoubleTooLow

A double was below its configured minimum.

Fields

found: f64
minimum: f64


DoubleTooHigh

A double was above its configured maximum.

Fields

found: f64
maximum: f64


ExpectedArgumentSeparator

A parsed argument had trailing non-whitespace data.

Implementations

Source

impl CommandSyntaxErrorKind

fn component(&self) -> TextComponent